featureflags.rest.models package
================================

Submodules
----------

featureflags.rest.models.authentication\_request module
-------------------------------------------------------

.. automodule:: featureflags.rest.models.authentication_request
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.authentication\_response module
--------------------------------------------------------

.. automodule:: featureflags.rest.models.authentication_response
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.clause module
--------------------------------------

.. automodule:: featureflags.rest.models.clause
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.distribution module
--------------------------------------------

.. automodule:: featureflags.rest.models.distribution
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.error module
-------------------------------------

.. automodule:: featureflags.rest.models.error
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.evaluation module
------------------------------------------

.. automodule:: featureflags.rest.models.evaluation
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.evaluation\_value module
-------------------------------------------------

.. automodule:: featureflags.rest.models.evaluation_value
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.evaluations module
-------------------------------------------

.. automodule:: featureflags.rest.models.evaluations
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.feature\_config module
-----------------------------------------------

.. automodule:: featureflags.rest.models.feature_config
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.feature\_config\_kind module
-----------------------------------------------------

.. automodule:: featureflags.rest.models.feature_config_kind
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.feature\_state module
----------------------------------------------

.. automodule:: featureflags.rest.models.feature_state
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.pagination module
------------------------------------------

.. automodule:: featureflags.rest.models.pagination
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.prerequisite module
--------------------------------------------

.. automodule:: featureflags.rest.models.prerequisite
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.segment module
---------------------------------------

.. automodule:: featureflags.rest.models.segment
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.serve module
-------------------------------------

.. automodule:: featureflags.rest.models.serve
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.serving\_rule module
---------------------------------------------

.. automodule:: featureflags.rest.models.serving_rule
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.tag module
-----------------------------------

.. automodule:: featureflags.rest.models.tag
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.variation module
-----------------------------------------

.. automodule:: featureflags.rest.models.variation
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.variation\_map module
----------------------------------------------

.. automodule:: featureflags.rest.models.variation_map
    :members:
    :undoc-members:
    :show-inheritance:

featureflags.rest.models.weighted\_variation module
---------------------------------------------------

.. automodule:: featureflags.rest.models.weighted_variation
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: featureflags.rest.models
    :members:
    :undoc-members:
    :show-inheritance:
